"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .configurationcontactref import (
    ConfigurationContactRef,
    ConfigurationContactRefTypedDict,
)
from codat_bankfeeds.types import BaseModel
import pydantic
from typing import List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class ConfigurationCustomerTypedDict(TypedDict):
    customer_options: NotRequired[List[ConfigurationContactRefTypedDict]]
    selected_customer_id: NotRequired[str]
    r"""Unique identifier for the customer."""


class ConfigurationCustomer(BaseModel):
    customer_options: Annotated[
        Optional[List[ConfigurationContactRef]], pydantic.Field(alias="customerOptions")
    ] = None

    selected_customer_id: Annotated[
        Optional[str], pydantic.Field(alias="selectedCustomerId")
    ] = None
    r"""Unique identifier for the customer."""
